@@ -18,11 +18,11 @@ Dancer::Plugin::Interchange6 - Interchange6 Shop Plugin for Dancer
 
 =head1 VERSION
 
-Version 0.008
+Version 0.009
 
 =cut
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 =head1 REQUIREMENTS
 
@@ -316,15 +316,17 @@ sub _shop_cart {
 
     $cart = Interchange6::Class->instantiate('Dancer::Plugin::Interchange6::Cart::DBIC',
                                        name => $name,
-                                       session_id => session->id,
-                                       run_hooks => sub {execute_hook(@_)});
+                                       sessions_id => session->id,
+                                       execute_hook => sub {execute_hook(@_)},
+                                   );
 
     if ($user_ref = logged_in_user) {
+
         $cart->load(users_id => $user_ref->users_id,
-                    session_id => session->id);
+                    sessions_id => session->id);
     }
     else {
-        $cart->load(session_id => session->id);
+        $cart->load(sessions_id => session->id);
     }
 
     return $cart;
